==> haskell-path-0.6.1-58-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-path.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: path
version: 0.6.1
id: path-0.6.1-8tGmnS4JcHKGC6c1QU7BjT
key: path-0.6.1-8tGmnS4JcHKGC6c1QU7BjT
license: BSD-3-Clause
copyright: 2015–2017 FP Complete
maintainer: Chris Done <chrisdone@fpcomplete.com>
author: Chris Done <chrisdone@fpcomplete.com>
synopsis: Support for well-typed paths
description:
    Support for well-typed paths.
category: System, Filesystem
abi: 31ebabb81ef4225273a50d043beac16e
exposed: True
exposed-modules:
    Path Path.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/path-0.6.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/path-0.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/path-0.6.1
hs-libraries: HSpath-0.6.1-8tGmnS4JcHKGC6c1QU7BjT
depends:
    aeson-1.4.0.0-5Oo1Sp1QUM1GMDoxqgB2DX base-4.11.1.0 deepseq-1.4.3.0
    exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf filepath-1.4.2
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg template-haskell-2.13.0.0
abi-depends: aeson-1.4.0.0-5Oo1Sp1QUM1GMDoxqgB2DX=703c560734a72c2a014a198df0039e3a
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf=7910067871295cb7f4f6699a852863a6
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
haddock-interfaces: /usr/share/doc/haskell-path/html/path.haddock
haddock-html: /usr/share/doc/haskell-path/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-path-0.6.1-59-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-path.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: path
version: 0.6.1
id: path-0.6.1-Hn4cBtP6iPULInG4NG7O0a
key: path-0.6.1-Hn4cBtP6iPULInG4NG7O0a
license: BSD-3-Clause
copyright: 2015–2017 FP Complete
maintainer: Chris Done <chrisdone@fpcomplete.com>
author: Chris Done <chrisdone@fpcomplete.com>
synopsis: Support for well-typed paths
description:
    Support for well-typed paths.
category: System, Filesystem
abi: a04d5e0ccc15126ff6892db00bd1ddbd
exposed: True
exposed-modules:
    Path Path.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/path-0.6.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/path-0.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/path-0.6.1
hs-libraries: HSpath-0.6.1-Hn4cBtP6iPULInG4NG7O0a
depends:
    aeson-1.4.0.0-9qWiRNFZVktJndCRfB1Mai base-4.11.1.0 deepseq-1.4.3.0
    exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf filepath-1.4.2
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg template-haskell-2.13.0.0
abi-depends: aeson-1.4.0.0-9qWiRNFZVktJndCRfB1Mai=107057a2dbf5fda7f784a80ae20f44b9
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf=7910067871295cb7f4f6699a852863a6
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
haddock-interfaces: /usr/share/doc/haskell-path/html/path.haddock
haddock-html: /usr/share/doc/haskell-path/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
